"""
File: math-xo-main.py
Name: math-xo
Version: 0.2
Autor: Carlo Smouter (lockwood)
Date created: 1/03/08
Last edited: 1/07/08
License: GPL V3
Changelog: /log/changelog.txt

Purpose: Educational Game For the One Laptop Per Child Project
         For practising basic math skills
"""
import pygame
import random
from pygame.locals import *

class Button(pygame.sprite.Sprite):
    """The buttons"""

    def __init__(self, image, value, posxy):
        pygame.sprite.Sprite.__init__(self)
        self.image = pygame.image.load(image).convert_alpha()
        self.posxy = posxy
        self.rect  = self.image.get_rect(topleft=(posxy))
        self.value = value
        

    def draw(self, surface):
        surface.blit(self.image, self.posxy)


class Main():

    def __init__(self):
        #init pygame
        pygame.init()
        pygame.display.set_caption("MATH-XO 0.2 by Lockwood")
        self.screen = pygame.display.set_mode((1200,900))

        self.logo = Button('data/logo.png', None, [550, 50])

        self.menu_buttons = []
        self.add_menu_button(Button("data/add.png", '+', [100, 50]))
        self.add_menu_button(Button("data/sub.png", '-', [100, 170]))
        self.add_menu_button(Button("data/mul.png", 'x', [100, 290]))
        #self.add_menu_button(Button("data/div.png", '/', [100, 410]))
        
        self.buttons = []
        self.add_button(Button("data/1.png", '1', [500, 500]))
        self.add_button(Button("data/2.png", '2', [590, 500]))
        self.add_button(Button("data/3.png", '3', [680, 500]))
        self.add_button(Button("data/4.png", '4', [770, 500]))
        self.add_button(Button("data/5.png", '5', [860, 500]))
        #part two
        self.add_button(Button("data/6.png", '6', [500, 590]))
        self.add_button(Button("data/7.png", '7', [590, 590]))
        self.add_button(Button("data/8.png", '8', [680, 590]))
        self.add_button(Button("data/9.png", '9', [770, 590]))
        self.add_button(Button("data/0.png", '0', [860, 590]))

        self.add_button(Button("data/minus.png", '-', [950, 590]))

        self.del_buttons = []
        self.add_del_button(Button("data/del.png", "", [410, 500]))

        self.acc_buttons = []
        self.add_acc_button(Button("data/acc.png", "", [950, 500]))

        self.MENU = '+'
        self.user_input = ''
        self.prize = ''
        self.counter = 0
        
        self.random_question('+')
        
        #console begin
        print "==math-xo 0.2 console=="
        print "\n"

    def random_question(self, menuval):
        self.randomA  = random.randint(0,10)
        self.randomB  = random.randint(0,10)
        if menuval == '+':
            self.answer   = self.randomA + self.randomB
        if menuval == '-':
            self.answer   = self.randomA - self.randomB
        if menuval == 'x':
            self.answer   = self.randomA * self.randomB
        if menuval == '/':
            self.answer   = self.randomA / self.randomB
        #print self.answer
        return self.randomA, self.randomB, self.answer 


    def check_question(self):
        
        try:
            if self.answer != int(self.user_input):
                print "Wrong answer!!!"
                self.prize = 'Wrong :('
            
            elif self.answer == int(self.user_input):
                print "Right answer!!!"
                self.prize = 'Right :)'

        except ValueError:
            print "<no input>"

    def update_input(self):
        return self.user_input

    def add_menu_button(self, menu_button):
        self.menu_buttons = self.menu_buttons + [menu_button]

    def add_button(self, button):
        self.buttons = self.buttons + [button]

    def add_del_button(self, del_button):
        self.del_buttons = self.del_buttons + [del_button]

    def add_acc_button(self, acc_button):
        self.acc_buttons = self.acc_buttons + [acc_button]

    def run(self):
        #run event loop
        self.loop()
        #pygame quiting
        pygame.quit()

    def loop(self):
        exit = False
        self.clock = pygame.time.Clock()

        while not exit:
            self.clock.tick(50)
            self.update_input()
            exit = self.EventHandler()
            self.draw()

    def EventHandler(self):
        exit = False
        for event in pygame.event.get():
            if event.type == QUIT:
                exit = True
            elif event.type == KEYDOWN:
                if event.key == K_ESCAPE:
                        exit = True
            elif event.type == MOUSEBUTTONDOWN:
                self.check_points(pygame.mouse.get_pos())
        return exit
                

    def check_points(self, (x, y)):
        
        for menu_button in self.menu_buttons:
            #print menu_button.value
            if menu_button.rect.collidepoint(x, y):
                self.MENU = menu_button.value
                #print "check_points menu_button MENU: ",self.MENU
                self.random_question(self.MENU)
                return self.MENU

        
        for button in self.buttons:
            if button.rect.collidepoint(x, y):
                self.user_input += button.value
                print "Pressed: ", button.value

        for del_button in self.del_buttons:
            if del_button.rect.collidepoint(x, y):
                print "Delete button pressed"
                self.user_input = ''
                return self.user_input
        
        for acc_button in self.acc_buttons:
            if acc_button.rect.collidepoint(x, y):
                print "--------------------------------------"
                print "accept button pressed"
                print self.user_input, "was given by the user"
                print "randomA:", self.randomA, "randomB:", self.randomB
                print "Question= ", self.randomA, self.MENU, self.randomB
                print "Answer = ", self.answer
                print "--------------------------------------"
                self.check_question()
                self.user_input = ''
                self.update_input()
                self.random_question(self.MENU)
                

        
                
    def draw(self):

        #the counter that counts to 200 (2sec), after that the self.prize
        #string empties
        self.counter += 1
        if self.counter >= 200:
            self.prize = ''
            self.counter = 0
            
        
        self.screen.fill((0,0,0))
        pygame.draw.rect(self.screen, (111,111,111), (0,0,300,900))
        font = pygame.font.Font("data/libserif.ttf", 40)
        text1 = font.render(self.user_input, 1, (255, 255, 255))
        text2 = font.render("%d %s %d"%(self.randomA ,self.MENU ,self.randomB), 1, (255, 255, 255))
        text3 = font.render("="  , 1, (255, 255, 255))
        text5 = font.render(self.prize, 1, (255, 255, 255))

        self.screen.blit(text1, [500, 300])
        self.screen.blit(text2, [700, 200])
        self.screen.blit(text3, [730, 250])
        self.screen.blit(text5, [680, 350])

        self.logo.draw(self.screen)

        #pygame.draw.rect(self.screen, (111,111,111), (0,0,400,900))
        #pygame.draw.line(self.screen, (255,255,255), (300,0), (300,900), 5)

        for menu_button in self.menu_buttons:
            menu_button.draw(self.screen)
        
        for button in self.buttons:
            button.draw(self.screen)
            
        for del_button in self.del_buttons:
            del_button.draw(self.screen)

        for acc_button in self.acc_buttons:
            acc_button.draw(self.screen)

            pygame.display.flip()

#start the program
Main().run()
